@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,7 +67,7 @@ import com.openexchange.server.osgiservice.ServiceRegistry;
  */
 public final class PasswordChangeServletActivator extends DeferredActivator {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(PasswordChangeServletActivator.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PasswordChangeServletActivator.class));
 
     private static final String PWC_SRVLT_ALIAS = "ajax/passwordchange";
 
@@ -127,10 +127,10 @@ public final class PasswordChangeServletActivator extends DeferredActivator {
                 final ServiceRegistry registry = getServiceRegistry();
                 registry.clearRegistry();
                 final Class<?>[] classes = getNeededServices();
-                for (int i = 0; i < classes.length; i++) {
-                    final Object service = getService(classes[i]);
+                for (final Class<?> classe : classes) {
+                    final Object service = getService(classe);
                     if (null != service) {
-                        registry.addService(classes[i], service);
+                        registry.addService(classe, service);
                     }
                 }
             }
